Enabled

Struct Enabled 

#[non_exhaustive]
pub struct Enabled {}
Token indicating that beta feature(s) are or can be enabled

When adding a new beta feature:

  • Put an instance of beta::Enabled in the appropriate piece of parsed template syntax, For example, in the SubstDetails along with the O:: markers.

  • When parsing, obtain the value from Enabled::new_for_syntax.

  • Add a test case to tests/minimal-ui/disabled.rs which omits the beta_deftly option, and therefore fails, thus demonstrating that the feature gate works as intended.

Implementations

Source

impl Enabled

pub fn new_for_dd_option(_: Span) -> Result<Self>

If the cargo feature is enabled, return Ok(Enabled)

Used when parsing the beta_deftly template option.

pub fn new_for_modules_feature(_: Span) -> Result<Self>

If the cargo feature is enabled, return Ok(Enabled)

Used for things that are inherently part of the modules feature, such as uses and define_derive_deftly_module!.

pub fn new_for_imported_definitions() -> Result<Enabled, &'static (dyn Fn(Span) -> Error + 'static)>

If the cargo feature is enabled, return Some.

Used when parsing template text imported from modules.

The rule is that modules have their own beta_deftly option, and beta features are allowed in module text iff the module enabled them. The importing template doesn’t need to.

pub fn new_for_syntax(span: Span) -> Result<Self>

If the beta_deftly template feature is enabled, return Ok(Enabled)

Used when parsing beta syntax, in templates.