#[non_exhaustive]pub struct Enabled {}Expand description
Token indicating that beta feature(s) are or can be enabled
When adding a new beta feature:
-
Put an instance of
beta::Enabledin the appropriate piece of parsed template syntax, For example, in theSubstDetailsalong with theO::markers. -
When parsing, obtain the value from
Enabled::new_for_syntax. -
Add a test case to
tests/minimal-ui/disabled.rswhich omits thebeta_deftlyoption, and therefore fails, thus demonstrating that the feature gate works as intended.
Implementations
Sourceimpl Enabled
impl Enabled
Sourcepub fn new_for_dd_option(_: Span) -> Result<Self>
pub fn new_for_dd_option(_: Span) -> Result<Self>
If the cargo feature is enabled, return Ok(Enabled)
Used when parsing the beta_deftly template option.
Sourcepub fn new_for_modules_feature(_: Span) -> Result<Self>
pub fn new_for_modules_feature(_: Span) -> Result<Self>
If the cargo feature is enabled, return Ok(Enabled)
Used for things that are inherently part of the modules feature,
such as uses and define_derive_deftly_module!.
Sourcepub fn new_for_imported_definitions() -> Result<Enabled, &'static (dyn Fn(Span) -> Error + 'static)>
pub fn new_for_imported_definitions() -> Result<Enabled, &'static (dyn Fn(Span) -> Error + 'static)>
If the cargo feature is enabled, return Some.
Used when parsing template text imported from modules.
The rule is that modules have their own beta_deftly option,
and beta features are allowed in module text iff the module
enabled them. The importing template doesn’t need to.
Sourcepub fn new_for_syntax(span: Span) -> Result<Self>
pub fn new_for_syntax(span: Span) -> Result<Self>
If the beta_deftly template feature is enabled, return Ok(Enabled)
Used when parsing beta syntax, in templates.